@@ -1,11 +1,14 @@
-from typing import List, Union
+import warnings
+from typing import Union
 
 import pytest
 from fastapi import FastAPI
-from fastapi.exceptions import FastAPIError
+from fastapi.exceptions import FastAPIError, ResponseValidationError
 from fastapi.responses import JSONResponse, Response
 from fastapi.testclient import TestClient
-from pydantic import BaseModel, ValidationError
+from pydantic import BaseModel
+
+from tests.utils import needs_pydanticv1
 
 
 class BaseUser(BaseModel):
@@ -189,7 +192,7 @@ def response_model_filtering_model_annotation_submodel_return_submodel() -> DBUs
     return DBUser(name="John", surname="Doe", password_hash="secret")
 
 
-@app.get("/response_model_list_of_model-no_annotation", response_model=List[User])
+@app.get("/response_model_list_of_model-no_annotation", response_model=list[User])
 def response_model_list_of_model_no_annotation():
     return [
         DBUser(name="John", surname="Doe", password_hash="secret"),
@@ -198,7 +201,7 @@ def response_model_list_of_model_no_annotation():
 
 
 @app.get("/no_response_model-annotation_list_of_model")
-def no_response_model_annotation_list_of_model() -> List[User]:
+def no_response_model_annotation_list_of_model() -> list[User]:
     return [
         DBUser(name="John", surname="Doe", password_hash="secret"),
         DBUser(name="Jane", surname="Does", password_hash="secret2"),
@@ -206,7 +209,7 @@ def no_response_model_annotation_list_of_model() -> List[User]:
 
 
 @app.get("/no_response_model-annotation_forward_ref_list_of_model")
-def no_response_model_annotation_forward_ref_list_of_model() -> "List[User]":
+def no_response_model_annotation_forward_ref_list_of_model() -> "list[User]":
     return [
         DBUser(name="John", surname="Doe", password_hash="secret"),
         DBUser(name="Jane", surname="Does", password_hash="secret2"),
@@ -277,13 +280,15 @@ def test_response_model_no_annotation_return_exact_dict():
 
 
 def test_response_model_no_annotation_return_invalid_dict():
-    with pytest.raises(ValidationError):
+    with pytest.raises(ResponseValidationError) as excinfo:
         client.get("/response_model-no_annotation-return_invalid_dict")
+    assert "missing" in str(excinfo.value)
 
 
 def test_response_model_no_annotation_return_invalid_model():
-    with pytest.raises(ValidationError):
+    with pytest.raises(ResponseValidationError) as excinfo:
         client.get("/response_model-no_annotation-return_invalid_model")
+    assert "missing" in str(excinfo.value)
 
 
 def test_response_model_no_annotation_return_dict_with_extra_data():
@@ -313,13 +318,15 @@ def test_no_response_model_annotation_return_exact_dict():
 
 
 def test_no_response_model_annotation_return_invalid_dict():
-    with pytest.raises(ValidationError):
+    with pytest.raises(ResponseValidationError) as excinfo:
         client.get("/no_response_model-annotation-return_invalid_dict")
+    assert "missing" in str(excinfo.value)
 
 
 def test_no_response_model_annotation_return_invalid_model():
-    with pytest.raises(ValidationError):
+    with pytest.raises(ResponseValidationError) as excinfo:
         client.get("/no_response_model-annotation-return_invalid_model")
+    assert "missing" in str(excinfo.value)
 
 
 def test_no_response_model_annotation_return_dict_with_extra_data():
@@ -395,13 +402,15 @@ def test_response_model_model1_annotation_model2_return_exact_dict():
 
 
 def test_response_model_model1_annotation_model2_return_invalid_dict():
-    with pytest.raises(ValidationError):
+    with pytest.raises(ResponseValidationError) as excinfo:
         client.get("/response_model_model1-annotation_model2-return_invalid_dict")
+    assert "missing" in str(excinfo.value)
 
 
 def test_response_model_model1_annotation_model2_return_invalid_model():
-    with pytest.raises(ValidationError):
+    with pytest.raises(ResponseValidationError) as excinfo:
         client.get("/response_model_model1-annotation_model2-return_invalid_model")
+    assert "missing" in str(excinfo.value)
 
 
 def test_response_model_model1_annotation_model2_return_dict_with_extra_data():
@@ -503,6 +512,29 @@ def test_invalid_response_model_field():
     assert "parameter response_model=None" in e.value.args[0]
 
 
+# TODO: remove when dropping Pydantic v1 support
+@needs_pydanticv1
+def test_invalid_response_model_field_pv1():
+    from fastapi._compat import v1
+
+    app = FastAPI()
+
+    class Model(v1.BaseModel):
+        foo: str
+
+    with warnings.catch_warnings(record=True):
+        warnings.simplefilter("always")
+
+        with pytest.raises(FastAPIError) as e:
+
+            @app.get("/")
+            def read_root() -> Union[Response, Model, None]:
+                return Response(content="Foo")  # pragma: no cover
+
+    assert "valid Pydantic field type" in e.value.args[0]
+    assert "parameter response_model=None" in e.value.args[0]
+
+
 def test_openapi_schema():
     response = client.get("/openapi.json")
     assert response.status_code == 200, response.text
