@@ -1,7 +1,26 @@
+import importlib
+from types import ModuleType
+
 import pytest
+from dirty_equals import IsDict
 from fastapi.testclient import TestClient
 
-from docs_src.cookie_params.tutorial001 import app
+from ...utils import needs_py310
+
+
+@pytest.fixture(
+    name="mod",
+    params=[
+        "tutorial001_py39",
+        pytest.param("tutorial001_py310", marks=needs_py310),
+        "tutorial001_an_py39",
+        pytest.param("tutorial001_an_py310", marks=needs_py310),
+    ],
+)
+def get_mod(request: pytest.FixtureRequest):
+    mod = importlib.import_module(f"docs_src.cookie_params.{request.param}")
+
+    return mod
 
 
 @pytest.mark.parametrize(
@@ -18,15 +37,15 @@ from docs_src.cookie_params.tutorial001 import app
         ("/items", {"session": "cookiesession"}, 200, {"ads_id": None}),
     ],
 )
-def test(path, cookies, expected_status, expected_response):
-    client = TestClient(app, cookies=cookies)
+def test(path, cookies, expected_status, expected_response, mod: ModuleType):
+    client = TestClient(mod.app, cookies=cookies)
     response = client.get(path)
     assert response.status_code == expected_status
     assert response.json() == expected_response
 
 
-def test_openapi_schema():
-    client = TestClient(app)
+def test_openapi_schema(mod: ModuleType):
+    client = TestClient(mod.app)
     response = client.get("/openapi.json")
     assert response.status_code == 200
     assert response.json() == {
@@ -56,7 +75,16 @@ def test_openapi_schema():
                     "parameters": [
                         {
                             "required": False,
-                            "schema": {"title": "Ads Id", "type": "string"},
+                            "schema": IsDict(
+                                {
+                                    "anyOf": [{"type": "string"}, {"type": "null"}],
+                                    "title": "Ads Id",
+                                }
+                            )
+                            | IsDict(
+                                # TODO: remove when deprecating Pydantic v1
+                                {"title": "Ads Id", "type": "string"}
+                            ),
                             "name": "ads_id",
                             "in": "cookie",
                         }
