@@ -1,12 +1,25 @@
+import importlib
+
+import pytest
 from dirty_equals import IsDict
 from fastapi.testclient import TestClient
 
-from docs_src.dependencies.tutorial006 import app
 
-client = TestClient(app)
+@pytest.fixture(
+    name="client",
+    params=[
+        pytest.param("tutorial006_py39"),
+        pytest.param("tutorial006_an_py39"),
+    ],
+)
+def get_client(request: pytest.FixtureRequest):
+    mod = importlib.import_module(f"docs_src.dependencies.{request.param}")
+
+    client = TestClient(mod.app)
+    return client
 
 
-def test_get_no_headers():
+def test_get_no_headers(client: TestClient):
     response = client.get("/items/")
     assert response.status_code == 422, response.text
     assert response.json() == IsDict(
@@ -45,13 +58,13 @@ def test_get_no_headers():
     )
 
 
-def test_get_invalid_one_header():
+def test_get_invalid_one_header(client: TestClient):
     response = client.get("/items/", headers={"X-Token": "invalid"})
     assert response.status_code == 400, response.text
     assert response.json() == {"detail": "X-Token header invalid"}
 
 
-def test_get_invalid_second_header():
+def test_get_invalid_second_header(client: TestClient):
     response = client.get(
         "/items/", headers={"X-Token": "fake-super-secret-token", "X-Key": "invalid"}
     )
@@ -59,7 +72,7 @@ def test_get_invalid_second_header():
     assert response.json() == {"detail": "X-Key header invalid"}
 
 
-def test_get_valid_headers():
+def test_get_valid_headers(client: TestClient):
     response = client.get(
         "/items/",
         headers={
@@ -71,7 +84,7 @@ def test_get_valid_headers():
     assert response.json() == [{"item": "Foo"}, {"item": "Bar"}]
 
 
-def test_openapi_schema():
+def test_openapi_schema(client: TestClient):
     response = client.get("/openapi.json")
     assert response.status_code == 200, response.text
     assert response.json() == {
