@@ -1,12 +1,25 @@
+import importlib
+
+import pytest
 from dirty_equals import IsDict
 from fastapi.testclient import TestClient
 
-from docs_src.dependencies.tutorial012 import app
 
-client = TestClient(app)
+@pytest.fixture(
+    name="client",
+    params=[
+        pytest.param("tutorial012_py39"),
+        pytest.param("tutorial012_an_py39"),
+    ],
+)
+def get_client(request: pytest.FixtureRequest):
+    mod = importlib.import_module(f"docs_src.dependencies.{request.param}")
+
+    client = TestClient(mod.app)
+    return client
 
 
-def test_get_no_headers_items():
+def test_get_no_headers_items(client: TestClient):
     response = client.get("/items/")
     assert response.status_code == 422, response.text
     assert response.json() == IsDict(
@@ -45,7 +58,7 @@ def test_get_no_headers_items():
     )
 
 
-def test_get_no_headers_users():
+def test_get_no_headers_users(client: TestClient):
     response = client.get("/users/")
     assert response.status_code == 422, response.text
     assert response.json() == IsDict(
@@ -84,19 +97,19 @@ def test_get_no_headers_users():
     )
 
 
-def test_get_invalid_one_header_items():
+def test_get_invalid_one_header_items(client: TestClient):
     response = client.get("/items/", headers={"X-Token": "invalid"})
     assert response.status_code == 400, response.text
     assert response.json() == {"detail": "X-Token header invalid"}
 
 
-def test_get_invalid_one_users():
+def test_get_invalid_one_users(client: TestClient):
     response = client.get("/users/", headers={"X-Token": "invalid"})
     assert response.status_code == 400, response.text
     assert response.json() == {"detail": "X-Token header invalid"}
 
 
-def test_get_invalid_second_header_items():
+def test_get_invalid_second_header_items(client: TestClient):
     response = client.get(
         "/items/", headers={"X-Token": "fake-super-secret-token", "X-Key": "invalid"}
     )
@@ -104,7 +117,7 @@ def test_get_invalid_second_header_items():
     assert response.json() == {"detail": "X-Key header invalid"}
 
 
-def test_get_invalid_second_header_users():
+def test_get_invalid_second_header_users(client: TestClient):
     response = client.get(
         "/users/", headers={"X-Token": "fake-super-secret-token", "X-Key": "invalid"}
     )
@@ -112,7 +125,7 @@ def test_get_invalid_second_header_users():
     assert response.json() == {"detail": "X-Key header invalid"}
 
 
-def test_get_valid_headers_items():
+def test_get_valid_headers_items(client: TestClient):
     response = client.get(
         "/items/",
         headers={
@@ -124,7 +137,7 @@ def test_get_valid_headers_items():
     assert response.json() == [{"item": "Portal Gun"}, {"item": "Plumbus"}]
 
 
-def test_get_valid_headers_users():
+def test_get_valid_headers_users(client: TestClient):
     response = client.get(
         "/users/",
         headers={
@@ -136,7 +149,7 @@ def test_get_valid_headers_users():
     assert response.json() == [{"username": "Rick"}, {"username": "Morty"}]
 
 
-def test_openapi_schema():
+def test_openapi_schema(client: TestClient):
     response = client.get("/openapi.json")
     assert response.status_code == 200, response.text
     assert response.json() == {
