@@ -1,11 +1,28 @@
+import importlib
+
+import pytest
 from fastapi.testclient import TestClient
 
-from docs_src.path_operation_configuration.tutorial005 import app
-
-client = TestClient(app)
+from ...utils import needs_py310
 
 
-def test_query_params_str_validations():
+@pytest.fixture(
+    name="client",
+    params=[
+        pytest.param("tutorial005_py39"),
+        pytest.param("tutorial005_py310", marks=needs_py310),
+    ],
+)
+def get_client(request: pytest.FixtureRequest):
+    mod = importlib.import_module(
+        f"docs_src.path_operation_configuration.{request.param}"
+    )
+
+    client = TestClient(mod.app)
+    return client
+
+
+def test_query_params_str_validations(client: TestClient):
     response = client.post("/items/", json={"name": "Foo", "price": 42})
     assert response.status_code == 200, response.text
     assert response.json() == {
@@ -17,7 +34,7 @@ def test_query_params_str_validations():
     }
 
 
-def test_openapi_schema():
+def test_openapi_schema(client: TestClient):
     response = client.get("/openapi.json")
     assert response.status_code == 200, response.text
     assert response.json() == {
@@ -68,9 +85,15 @@ def test_openapi_schema():
                     "type": "object",
                     "properties": {
                         "name": {"title": "Name", "type": "string"},
+                        "description": {
+                            "title": "Description",
+                            "anyOf": [{"type": "string"}, {"type": "null"}],
+                        },
                         "price": {"title": "Price", "type": "number"},
-                        "description": {"title": "Description", "type": "string"},
-                        "tax": {"title": "Tax", "type": "number"},
+                        "tax": {
+                            "title": "Tax",
+                            "anyOf": [{"type": "number"}, {"type": "null"}],
+                        },
                         "tags": {
                             "title": "Tags",
                             "uniqueItems": True,
